We test whether x and y are conditionally associated, given S using a generalized linear model.

psi_hat_sl(y, x, S=c(), subset = NULL, out_bin = TRUE, exp_bin = FALSE, 
sl=NULL,cross_fitting = FALSE,kfolds=5)

Arguments

y

Outcome variable, either binary or numeric

x

Exposure variable, either binary or numeric

S

Conditional variable set, can be empty

subset

Optionally, control the subset of the dataset to be used

out_bin

A logical evaluating to TRUE or FALSE indicating whether outcome variable is binary.

exp_bin

A logical evaluating to TRUE or FALSE indicating whether exposure variable is binary.

sl

Character string specifying models applied in super learning

cross_fitting

A logical evaluating to TRUE or FALSE indicating whether cross-fitting is used.

kfolds

A numeric indicating how many folds is used for cross-fitting if applied

Value

Test statistics and standard error of the test.

Details

All included variables should be either numeric or binary. If y is numeric, the default method is linear regression model, mean response,MARS, random forest and XGBoost. If y is binary, the default method is LDA, mean response,MARS, random forest and XGBoost. This model is tested whether x and y is independent conditional on S. The final result is the test statistics and standard error.