We test whether x and y are conditionally associated, given
S, using specific methods.
ortest(x, y, S, suffStat)The position of the exposure variable
The position of the exposure variable
The position of the conditional variable set
A list with elements needed for the test:
Data matrix where columns represent variables.
The method used for the test: "sl", "linear", "linear_int"
Specifies the super learning model. If y is numeric, the default method is linear regression model, mean response,MARS, random forest and XGBoost. If y is binary, the default method is LDA, mean response,MARS, random forest and XGBoost.
Logical; whether cross-fitting is used in super learning.
Number of folds for cross-fitting.
Logical; whether to include two-way interactions between variables in S.
Logical; whether to include three-way interactions between variables in S.
p-value for model y ~ x + S.
This function test whether x and y is independent conditional on
S. The final result only includes p value for model y ~ x + S.